"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6142 import (
        AbstractAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6143 import (
        AbstractShaftHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6144 import (
        AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6145 import (
        AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6146 import (
        AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6147 import (
        AGMAGleasonConicalGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6148 import (
        AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6149 import (
        AssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6150 import (
        BearingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6151 import (
        BeltConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6152 import (
        BeltDriveHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6153 import (
        BevelDifferentialGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6154 import (
        BevelDifferentialGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6155 import (
        BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6156 import (
        BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6157 import (
        BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6158 import (
        BevelGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6159 import (
        BevelGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6160 import (
        BevelGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6161 import (
        BoltedJointHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6162 import (
        BoltHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6163 import (
        ClutchConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6164 import (
        ClutchHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6165 import (
        ClutchHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6166 import (
        CoaxialConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6167 import (
        ComponentHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6168 import (
        ConceptCouplingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6169 import (
        ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6170 import (
        ConceptCouplingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6171 import (
        ConceptGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6172 import (
        ConceptGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6173 import (
        ConceptGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6174 import (
        ConicalGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6175 import (
        ConicalGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6176 import (
        ConicalGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6177 import (
        ConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6178 import (
        ConnectorHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6179 import (
        CouplingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6180 import (
        CouplingHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6181 import (
        CouplingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6182 import (
        CVTBeltConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6183 import (
        CVTHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6184 import (
        CVTPulleyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6185 import (
        CycloidalAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6186 import (
        CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6187 import (
        CycloidalDiscHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6188 import (
        CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6189 import (
        CylindricalGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6190 import (
        CylindricalGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6191 import (
        CylindricalGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6192 import (
        CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6193 import (
        DatumHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6194 import (
        ExternalCADModelHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6195 import (
        FaceGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6196 import (
        FaceGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6197 import (
        FaceGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6198 import (
        FEPartHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6199 import (
        FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6200 import (
        GearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6201 import (
        GearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6202 import (
        GearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6203 import (
        GuideDxfModelHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6204 import (
        HarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6205 import (
        HypoidGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6206 import (
        HypoidGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6207 import (
        HypoidGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6208 import (
        InterMountableComponentConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6209 import (
        KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6210 import (
        KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6211 import (
        KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6212 import (
        KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6213 import (
        KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6214 import (
        KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6215 import (
        KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6216 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6217 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6218 import (
        MassDiscHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6219 import (
        MeasurementComponentHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6220 import (
        MicrophoneArrayHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6221 import (
        MicrophoneHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6222 import (
        ModalAnalysisForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6223 import (
        MountableComponentHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6224 import (
        OilSealHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6225 import (
        PartHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6226 import (
        PartToPartShearCouplingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6227 import (
        PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6228 import (
        PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6229 import (
        PlanetaryConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6230 import (
        PlanetaryGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6231 import (
        PlanetCarrierHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6232 import (
        PointLoadHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6233 import (
        PowerLoadHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6234 import (
        PulleyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6235 import (
        RingPinsHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6236 import (
        RingPinsToDiscConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6237 import (
        RollingRingAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6238 import (
        RollingRingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6239 import (
        RollingRingHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6240 import (
        RootAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6241 import (
        ShaftHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6242 import (
        ShaftHubConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6243 import (
        ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6244 import (
        SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6245 import (
        SpiralBevelGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6246 import (
        SpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6247 import (
        SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6248 import (
        SpringDamperConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6249 import (
        SpringDamperHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6250 import (
        SpringDamperHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6251 import (
        StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6252 import (
        StraightBevelDiffGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6253 import (
        StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6254 import (
        StraightBevelGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6255 import (
        StraightBevelGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6256 import (
        StraightBevelGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6257 import (
        StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6258 import (
        StraightBevelSunGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6259 import (
        SynchroniserHalfHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6260 import (
        SynchroniserHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6261 import (
        SynchroniserPartHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6262 import (
        SynchroniserSleeveHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6263 import (
        TorqueConverterConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6264 import (
        TorqueConverterHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6265 import (
        TorqueConverterPumpHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6266 import (
        TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6267 import (
        UnbalancedMassHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6268 import (
        VirtualComponentHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6269 import (
        WormGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6270 import (
        WormGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6271 import (
        WormGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6272 import (
        ZerolBevelGearHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6273 import (
        ZerolBevelGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6274 import (
        ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6142": [
            "AbstractAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6143": [
            "AbstractShaftHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6144": [
            "AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6145": [
            "AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6146": [
            "AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6147": [
            "AGMAGleasonConicalGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6148": [
            "AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6149": [
            "AssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6150": [
            "BearingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6151": [
            "BeltConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6152": [
            "BeltDriveHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6153": [
            "BevelDifferentialGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6154": [
            "BevelDifferentialGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6155": [
            "BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6156": [
            "BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6157": [
            "BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6158": [
            "BevelGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6159": [
            "BevelGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6160": [
            "BevelGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6161": [
            "BoltedJointHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6162": [
            "BoltHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6163": [
            "ClutchConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6164": [
            "ClutchHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6165": [
            "ClutchHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6166": [
            "CoaxialConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6167": [
            "ComponentHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6168": [
            "ConceptCouplingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6169": [
            "ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6170": [
            "ConceptCouplingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6171": [
            "ConceptGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6172": [
            "ConceptGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6173": [
            "ConceptGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6174": [
            "ConicalGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6175": [
            "ConicalGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6176": [
            "ConicalGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6177": [
            "ConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6178": [
            "ConnectorHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6179": [
            "CouplingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6180": [
            "CouplingHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6181": [
            "CouplingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6182": [
            "CVTBeltConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6183": [
            "CVTHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6184": [
            "CVTPulleyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6185": [
            "CycloidalAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6186": [
            "CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6187": [
            "CycloidalDiscHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6188": [
            "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6189": [
            "CylindricalGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6190": [
            "CylindricalGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6191": [
            "CylindricalGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6192": [
            "CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6193": [
            "DatumHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6194": [
            "ExternalCADModelHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6195": [
            "FaceGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6196": [
            "FaceGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6197": [
            "FaceGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6198": [
            "FEPartHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6199": [
            "FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6200": [
            "GearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6201": [
            "GearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6202": [
            "GearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6203": [
            "GuideDxfModelHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6204": [
            "HarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6205": [
            "HypoidGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6206": [
            "HypoidGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6207": [
            "HypoidGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6208": [
            "InterMountableComponentConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6209": [
            "KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6210": [
            "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6211": [
            "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6212": [
            "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6213": [
            "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6214": [
            "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6215": [
            "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6216": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6217": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6218": [
            "MassDiscHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6219": [
            "MeasurementComponentHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6220": [
            "MicrophoneArrayHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6221": [
            "MicrophoneHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6222": [
            "ModalAnalysisForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6223": [
            "MountableComponentHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6224": [
            "OilSealHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6225": [
            "PartHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6226": [
            "PartToPartShearCouplingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6227": [
            "PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6228": [
            "PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6229": [
            "PlanetaryConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6230": [
            "PlanetaryGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6231": [
            "PlanetCarrierHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6232": [
            "PointLoadHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6233": [
            "PowerLoadHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6234": [
            "PulleyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6235": [
            "RingPinsHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6236": [
            "RingPinsToDiscConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6237": [
            "RollingRingAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6238": [
            "RollingRingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6239": [
            "RollingRingHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6240": [
            "RootAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6241": [
            "ShaftHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6242": [
            "ShaftHubConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6243": [
            "ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6244": [
            "SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6245": [
            "SpiralBevelGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6246": [
            "SpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6247": [
            "SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6248": [
            "SpringDamperConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6249": [
            "SpringDamperHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6250": [
            "SpringDamperHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6251": [
            "StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6252": [
            "StraightBevelDiffGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6253": [
            "StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6254": [
            "StraightBevelGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6255": [
            "StraightBevelGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6256": [
            "StraightBevelGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6257": [
            "StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6258": [
            "StraightBevelSunGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6259": [
            "SynchroniserHalfHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6260": [
            "SynchroniserHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6261": [
            "SynchroniserPartHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6262": [
            "SynchroniserSleeveHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6263": [
            "TorqueConverterConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6264": [
            "TorqueConverterHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6265": [
            "TorqueConverterPumpHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6266": [
            "TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6267": [
            "UnbalancedMassHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6268": [
            "VirtualComponentHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6269": [
            "WormGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6270": [
            "WormGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6271": [
            "WormGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6272": [
            "ZerolBevelGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6273": [
            "ZerolBevelGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses_single_excitation._6274": [
            "ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyHarmonicAnalysisOfSingleExcitation",
    "AbstractShaftHarmonicAnalysisOfSingleExcitation",
    "AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation",
    "AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    "AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation",
    "AGMAGleasonConicalGearMeshHarmonicAnalysisOfSingleExcitation",
    "AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation",
    "AssemblyHarmonicAnalysisOfSingleExcitation",
    "BearingHarmonicAnalysisOfSingleExcitation",
    "BeltConnectionHarmonicAnalysisOfSingleExcitation",
    "BeltDriveHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialGearHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialGearMeshHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation",
    "BevelGearHarmonicAnalysisOfSingleExcitation",
    "BevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "BevelGearSetHarmonicAnalysisOfSingleExcitation",
    "BoltedJointHarmonicAnalysisOfSingleExcitation",
    "BoltHarmonicAnalysisOfSingleExcitation",
    "ClutchConnectionHarmonicAnalysisOfSingleExcitation",
    "ClutchHalfHarmonicAnalysisOfSingleExcitation",
    "ClutchHarmonicAnalysisOfSingleExcitation",
    "CoaxialConnectionHarmonicAnalysisOfSingleExcitation",
    "ComponentHarmonicAnalysisOfSingleExcitation",
    "ConceptCouplingConnectionHarmonicAnalysisOfSingleExcitation",
    "ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation",
    "ConceptCouplingHarmonicAnalysisOfSingleExcitation",
    "ConceptGearHarmonicAnalysisOfSingleExcitation",
    "ConceptGearMeshHarmonicAnalysisOfSingleExcitation",
    "ConceptGearSetHarmonicAnalysisOfSingleExcitation",
    "ConicalGearHarmonicAnalysisOfSingleExcitation",
    "ConicalGearMeshHarmonicAnalysisOfSingleExcitation",
    "ConicalGearSetHarmonicAnalysisOfSingleExcitation",
    "ConnectionHarmonicAnalysisOfSingleExcitation",
    "ConnectorHarmonicAnalysisOfSingleExcitation",
    "CouplingConnectionHarmonicAnalysisOfSingleExcitation",
    "CouplingHalfHarmonicAnalysisOfSingleExcitation",
    "CouplingHarmonicAnalysisOfSingleExcitation",
    "CVTBeltConnectionHarmonicAnalysisOfSingleExcitation",
    "CVTHarmonicAnalysisOfSingleExcitation",
    "CVTPulleyHarmonicAnalysisOfSingleExcitation",
    "CycloidalAssemblyHarmonicAnalysisOfSingleExcitation",
    "CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation",
    "CycloidalDiscHarmonicAnalysisOfSingleExcitation",
    "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysisOfSingleExcitation",
    "CylindricalGearHarmonicAnalysisOfSingleExcitation",
    "CylindricalGearMeshHarmonicAnalysisOfSingleExcitation",
    "CylindricalGearSetHarmonicAnalysisOfSingleExcitation",
    "CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation",
    "DatumHarmonicAnalysisOfSingleExcitation",
    "ExternalCADModelHarmonicAnalysisOfSingleExcitation",
    "FaceGearHarmonicAnalysisOfSingleExcitation",
    "FaceGearMeshHarmonicAnalysisOfSingleExcitation",
    "FaceGearSetHarmonicAnalysisOfSingleExcitation",
    "FEPartHarmonicAnalysisOfSingleExcitation",
    "FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation",
    "GearHarmonicAnalysisOfSingleExcitation",
    "GearMeshHarmonicAnalysisOfSingleExcitation",
    "GearSetHarmonicAnalysisOfSingleExcitation",
    "GuideDxfModelHarmonicAnalysisOfSingleExcitation",
    "HarmonicAnalysisOfSingleExcitation",
    "HypoidGearHarmonicAnalysisOfSingleExcitation",
    "HypoidGearMeshHarmonicAnalysisOfSingleExcitation",
    "HypoidGearSetHarmonicAnalysisOfSingleExcitation",
    "InterMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation",
    "MassDiscHarmonicAnalysisOfSingleExcitation",
    "MeasurementComponentHarmonicAnalysisOfSingleExcitation",
    "MicrophoneArrayHarmonicAnalysisOfSingleExcitation",
    "MicrophoneHarmonicAnalysisOfSingleExcitation",
    "ModalAnalysisForHarmonicAnalysis",
    "MountableComponentHarmonicAnalysisOfSingleExcitation",
    "OilSealHarmonicAnalysisOfSingleExcitation",
    "PartHarmonicAnalysisOfSingleExcitation",
    "PartToPartShearCouplingConnectionHarmonicAnalysisOfSingleExcitation",
    "PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation",
    "PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation",
    "PlanetaryConnectionHarmonicAnalysisOfSingleExcitation",
    "PlanetaryGearSetHarmonicAnalysisOfSingleExcitation",
    "PlanetCarrierHarmonicAnalysisOfSingleExcitation",
    "PointLoadHarmonicAnalysisOfSingleExcitation",
    "PowerLoadHarmonicAnalysisOfSingleExcitation",
    "PulleyHarmonicAnalysisOfSingleExcitation",
    "RingPinsHarmonicAnalysisOfSingleExcitation",
    "RingPinsToDiscConnectionHarmonicAnalysisOfSingleExcitation",
    "RollingRingAssemblyHarmonicAnalysisOfSingleExcitation",
    "RollingRingConnectionHarmonicAnalysisOfSingleExcitation",
    "RollingRingHarmonicAnalysisOfSingleExcitation",
    "RootAssemblyHarmonicAnalysisOfSingleExcitation",
    "ShaftHarmonicAnalysisOfSingleExcitation",
    "ShaftHubConnectionHarmonicAnalysisOfSingleExcitation",
    "ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    "SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation",
    "SpiralBevelGearHarmonicAnalysisOfSingleExcitation",
    "SpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation",
    "SpringDamperConnectionHarmonicAnalysisOfSingleExcitation",
    "SpringDamperHalfHarmonicAnalysisOfSingleExcitation",
    "SpringDamperHarmonicAnalysisOfSingleExcitation",
    "StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation",
    "StraightBevelDiffGearMeshHarmonicAnalysisOfSingleExcitation",
    "StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation",
    "StraightBevelGearHarmonicAnalysisOfSingleExcitation",
    "StraightBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "StraightBevelGearSetHarmonicAnalysisOfSingleExcitation",
    "StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation",
    "StraightBevelSunGearHarmonicAnalysisOfSingleExcitation",
    "SynchroniserHalfHarmonicAnalysisOfSingleExcitation",
    "SynchroniserHarmonicAnalysisOfSingleExcitation",
    "SynchroniserPartHarmonicAnalysisOfSingleExcitation",
    "SynchroniserSleeveHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterConnectionHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterPumpHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation",
    "UnbalancedMassHarmonicAnalysisOfSingleExcitation",
    "VirtualComponentHarmonicAnalysisOfSingleExcitation",
    "WormGearHarmonicAnalysisOfSingleExcitation",
    "WormGearMeshHarmonicAnalysisOfSingleExcitation",
    "WormGearSetHarmonicAnalysisOfSingleExcitation",
    "ZerolBevelGearHarmonicAnalysisOfSingleExcitation",
    "ZerolBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation",
)



"""CylindricalGearSetOptimisationWrapper"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_SET_OPTIMISATION_WRAPPER = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical",
    "CylindricalGearSetOptimisationWrapper",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="CylindricalGearSetOptimisationWrapper")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalGearSetOptimisationWrapper._Cast_CylindricalGearSetOptimisationWrapper",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearSetOptimisationWrapper",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalGearSetOptimisationWrapper:
    """Special nested class for casting CylindricalGearSetOptimisationWrapper to subclasses."""

    __parent__: "CylindricalGearSetOptimisationWrapper"

    @property
    def cylindrical_gear_set_optimisation_wrapper(
        self: "CastSelf",
    ) -> "CylindricalGearSetOptimisationWrapper":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CylindricalGearSetOptimisationWrapper(_0.APIBase):
    """CylindricalGearSetOptimisationWrapper

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_GEAR_SET_OPTIMISATION_WRAPPER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def face_width(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.FaceWidth

        if temp is None:
            return 0.0

        return temp

    @face_width.setter
    @enforce_parameter_types
    def face_width(self: "Self", value: "float") -> None:
        self.wrapped.FaceWidth = float(value) if value is not None else 0.0

    @property
    def face_width_with_constant_axial_contact_ratio(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.FaceWidthWithConstantAxialContactRatio

        if temp is None:
            return 0.0

        return temp

    @face_width_with_constant_axial_contact_ratio.setter
    @enforce_parameter_types
    def face_width_with_constant_axial_contact_ratio(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.FaceWidthWithConstantAxialContactRatio = (
            float(value) if value is not None else 0.0
        )

    @property
    def helix_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.HelixAngle

        if temp is None:
            return 0.0

        return temp

    @helix_angle.setter
    @enforce_parameter_types
    def helix_angle(self: "Self", value: "float") -> None:
        self.wrapped.HelixAngle = float(value) if value is not None else 0.0

    @property
    def helix_angle_fixed_transverse_profile(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.HelixAngleFixedTransverseProfile

        if temp is None:
            return 0.0

        return temp

    @helix_angle_fixed_transverse_profile.setter
    @enforce_parameter_types
    def helix_angle_fixed_transverse_profile(self: "Self", value: "float") -> None:
        self.wrapped.HelixAngleFixedTransverseProfile = (
            float(value) if value is not None else 0.0
        )

    @property
    def normal_module(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.NormalModule

        if temp is None:
            return 0.0

        return temp

    @normal_module.setter
    @enforce_parameter_types
    def normal_module(self: "Self", value: "float") -> None:
        self.wrapped.NormalModule = float(value) if value is not None else 0.0

    @property
    def normal_pressure_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.NormalPressureAngle

        if temp is None:
            return 0.0

        return temp

    @normal_pressure_angle.setter
    @enforce_parameter_types
    def normal_pressure_angle(self: "Self", value: "float") -> None:
        self.wrapped.NormalPressureAngle = float(value) if value is not None else 0.0

    @property
    def planet_diameter_with_adjusted_face_width_to_maintain_mass(
        self: "Self",
    ) -> "float":
        """float"""
        temp = self.wrapped.PlanetDiameterWithAdjustedFaceWidthToMaintainMass

        if temp is None:
            return 0.0

        return temp

    @planet_diameter_with_adjusted_face_width_to_maintain_mass.setter
    @enforce_parameter_types
    def planet_diameter_with_adjusted_face_width_to_maintain_mass(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.PlanetDiameterWithAdjustedFaceWidthToMaintainMass = (
            float(value) if value is not None else 0.0
        )

    @property
    def root_gear_profile_shift_coefficient(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RootGearProfileShiftCoefficient

        if temp is None:
            return 0.0

        return temp

    @root_gear_profile_shift_coefficient.setter
    @enforce_parameter_types
    def root_gear_profile_shift_coefficient(self: "Self", value: "float") -> None:
        self.wrapped.RootGearProfileShiftCoefficient = (
            float(value) if value is not None else 0.0
        )

    @property
    def root_gear_profile_shift_coefficient_with_fixed_tip_and_root_diameters(
        self: "Self",
    ) -> "float":
        """float"""
        temp = self.wrapped.RootGearProfileShiftCoefficientWithFixedTipAndRootDiameters

        if temp is None:
            return 0.0

        return temp

    @root_gear_profile_shift_coefficient_with_fixed_tip_and_root_diameters.setter
    @enforce_parameter_types
    def root_gear_profile_shift_coefficient_with_fixed_tip_and_root_diameters(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.RootGearProfileShiftCoefficientWithFixedTipAndRootDiameters = (
            float(value) if value is not None else 0.0
        )

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalGearSetOptimisationWrapper":
        """Cast to another type.

        Returns:
            _Cast_CylindricalGearSetOptimisationWrapper
        """
        return _Cast_CylindricalGearSetOptimisationWrapper(self)



"""SimpleVelocityBasedStepHalvingTransientSolver"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.nodal_analysis.system_solvers import _117
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_SIMPLE_VELOCITY_BASED_STEP_HALVING_TRANSIENT_SOLVER = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.SystemSolvers",
    "SimpleVelocityBasedStepHalvingTransientSolver",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.nodal_analysis.system_solvers import (
        _103,
        _109,
        _107,
        _119,
        _106,
        _118,
        _116,
    )

    Self = TypeVar("Self", bound="SimpleVelocityBasedStepHalvingTransientSolver")
    CastSelf = TypeVar(
        "CastSelf",
        bound="SimpleVelocityBasedStepHalvingTransientSolver._Cast_SimpleVelocityBasedStepHalvingTransientSolver",
    )


__docformat__ = "restructuredtext en"
__all__ = ("SimpleVelocityBasedStepHalvingTransientSolver",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SimpleVelocityBasedStepHalvingTransientSolver:
    """Special nested class for casting SimpleVelocityBasedStepHalvingTransientSolver to subclasses."""

    __parent__: "SimpleVelocityBasedStepHalvingTransientSolver"

    @property
    def step_halving_transient_solver(
        self: "CastSelf",
    ) -> "_117.StepHalvingTransientSolver":
        return self.__parent__._cast(_117.StepHalvingTransientSolver)

    @property
    def internal_transient_solver(self: "CastSelf") -> "_107.InternalTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _107

        return self.__parent__._cast(_107.InternalTransientSolver)

    @property
    def transient_solver(self: "CastSelf") -> "_119.TransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _119

        return self.__parent__._cast(_119.TransientSolver)

    @property
    def dynamic_solver(self: "CastSelf") -> "_106.DynamicSolver":
        from mastapy._private.nodal_analysis.system_solvers import _106

        return self.__parent__._cast(_106.DynamicSolver)

    @property
    def stiffness_solver(self: "CastSelf") -> "_118.StiffnessSolver":
        from mastapy._private.nodal_analysis.system_solvers import _118

        return self.__parent__._cast(_118.StiffnessSolver)

    @property
    def solver(self: "CastSelf") -> "_116.Solver":
        from mastapy._private.nodal_analysis.system_solvers import _116

        return self.__parent__._cast(_116.Solver)

    @property
    def backward_euler_transient_solver(
        self: "CastSelf",
    ) -> "_103.BackwardEulerTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _103

        return self.__parent__._cast(_103.BackwardEulerTransientSolver)

    @property
    def newmark_transient_solver(self: "CastSelf") -> "_109.NewmarkTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _109

        return self.__parent__._cast(_109.NewmarkTransientSolver)

    @property
    def simple_velocity_based_step_halving_transient_solver(
        self: "CastSelf",
    ) -> "SimpleVelocityBasedStepHalvingTransientSolver":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class SimpleVelocityBasedStepHalvingTransientSolver(_117.StepHalvingTransientSolver):
    """SimpleVelocityBasedStepHalvingTransientSolver

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SIMPLE_VELOCITY_BASED_STEP_HALVING_TRANSIENT_SOLVER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_SimpleVelocityBasedStepHalvingTransientSolver":
        """Cast to another type.

        Returns:
            _Cast_SimpleVelocityBasedStepHalvingTransientSolver
        """
        return _Cast_SimpleVelocityBasedStepHalvingTransientSolver(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.bearings.bearing_results.rolling.abma._2168 import (
        ANSIABMA112014Results,
    )
    from mastapy._private.bearings.bearing_results.rolling.abma._2169 import (
        ANSIABMA92015Results,
    )
    from mastapy._private.bearings.bearing_results.rolling.abma._2170 import (
        ANSIABMAResults,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.bearings.bearing_results.rolling.abma._2168": [
            "ANSIABMA112014Results"
        ],
        "_private.bearings.bearing_results.rolling.abma._2169": [
            "ANSIABMA92015Results"
        ],
        "_private.bearings.bearing_results.rolling.abma._2170": ["ANSIABMAResults"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "ANSIABMA112014Results",
    "ANSIABMA92015Results",
    "ANSIABMAResults",
)



"""WormGearDutyCycleRating"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.rating import _368
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_WORM_GEAR_DUTY_CYCLE_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Worm", "WormGearDutyCycleRating"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.gears.rating import _369, _364
    from mastapy._private.gears.rating.worm import _386, _385
    from mastapy._private.gears.analysis import _1253

    Self = TypeVar("Self", bound="WormGearDutyCycleRating")
    CastSelf = TypeVar(
        "CastSelf", bound="WormGearDutyCycleRating._Cast_WormGearDutyCycleRating"
    )


__docformat__ = "restructuredtext en"
__all__ = ("WormGearDutyCycleRating",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_WormGearDutyCycleRating:
    """Special nested class for casting WormGearDutyCycleRating to subclasses."""

    __parent__: "WormGearDutyCycleRating"

    @property
    def gear_duty_cycle_rating(self: "CastSelf") -> "_368.GearDutyCycleRating":
        return self.__parent__._cast(_368.GearDutyCycleRating)

    @property
    def abstract_gear_rating(self: "CastSelf") -> "_364.AbstractGearRating":
        from mastapy._private.gears.rating import _364

        return self.__parent__._cast(_364.AbstractGearRating)

    @property
    def abstract_gear_analysis(self: "CastSelf") -> "_1253.AbstractGearAnalysis":
        from mastapy._private.gears.analysis import _1253

        return self.__parent__._cast(_1253.AbstractGearAnalysis)

    @property
    def worm_gear_duty_cycle_rating(self: "CastSelf") -> "WormGearDutyCycleRating":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class WormGearDutyCycleRating(_368.GearDutyCycleRating):
    """WormGearDutyCycleRating

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _WORM_GEAR_DUTY_CYCLE_RATING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def left_flank_rating(self: "Self") -> "_369.GearFlankRating":
        """mastapy._private.gears.rating.GearFlankRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LeftFlankRating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def right_flank_rating(self: "Self") -> "_369.GearFlankRating":
        """mastapy._private.gears.rating.GearFlankRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RightFlankRating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def gear_set_design_duty_cycle(self: "Self") -> "_386.WormGearSetDutyCycleRating":
        """mastapy._private.gears.rating.worm.WormGearSetDutyCycleRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearSetDesignDutyCycle

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def worm_gear_set_design_duty_cycle(
        self: "Self",
    ) -> "_386.WormGearSetDutyCycleRating":
        """mastapy._private.gears.rating.worm.WormGearSetDutyCycleRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WormGearSetDesignDutyCycle

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def gear_ratings(self: "Self") -> "List[_385.WormGearRating]":
        """List[mastapy._private.gears.rating.worm.WormGearRating]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearRatings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def worm_gear_ratings(self: "Self") -> "List[_385.WormGearRating]":
        """List[mastapy._private.gears.rating.worm.WormGearRating]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WormGearRatings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_WormGearDutyCycleRating":
        """Cast to another type.

        Returns:
            _Cast_WormGearDutyCycleRating
        """
        return _Cast_WormGearDutyCycleRating(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.part_model.couplings._2633 import BeltDrive
    from mastapy._private.system_model.part_model.couplings._2634 import BeltDriveType
    from mastapy._private.system_model.part_model.couplings._2635 import Clutch
    from mastapy._private.system_model.part_model.couplings._2636 import ClutchHalf
    from mastapy._private.system_model.part_model.couplings._2637 import ClutchType
    from mastapy._private.system_model.part_model.couplings._2638 import ConceptCoupling
    from mastapy._private.system_model.part_model.couplings._2639 import (
        ConceptCouplingHalf,
    )
    from mastapy._private.system_model.part_model.couplings._2640 import (
        ConceptCouplingHalfPositioning,
    )
    from mastapy._private.system_model.part_model.couplings._2641 import Coupling
    from mastapy._private.system_model.part_model.couplings._2642 import CouplingHalf
    from mastapy._private.system_model.part_model.couplings._2643 import (
        CrowningSpecification,
    )
    from mastapy._private.system_model.part_model.couplings._2644 import CVT
    from mastapy._private.system_model.part_model.couplings._2645 import CVTPulley
    from mastapy._private.system_model.part_model.couplings._2646 import (
        PartToPartShearCoupling,
    )
    from mastapy._private.system_model.part_model.couplings._2647 import (
        PartToPartShearCouplingHalf,
    )
    from mastapy._private.system_model.part_model.couplings._2648 import (
        PitchErrorFlankOptions,
    )
    from mastapy._private.system_model.part_model.couplings._2649 import Pulley
    from mastapy._private.system_model.part_model.couplings._2650 import (
        RigidConnectorStiffnessType,
    )
    from mastapy._private.system_model.part_model.couplings._2651 import (
        RigidConnectorTiltStiffnessTypes,
    )
    from mastapy._private.system_model.part_model.couplings._2652 import (
        RigidConnectorToothLocation,
    )
    from mastapy._private.system_model.part_model.couplings._2653 import (
        RigidConnectorToothSpacingType,
    )
    from mastapy._private.system_model.part_model.couplings._2654 import (
        RigidConnectorTypes,
    )
    from mastapy._private.system_model.part_model.couplings._2655 import RollingRing
    from mastapy._private.system_model.part_model.couplings._2656 import (
        RollingRingAssembly,
    )
    from mastapy._private.system_model.part_model.couplings._2657 import (
        ShaftHubConnection,
    )
    from mastapy._private.system_model.part_model.couplings._2658 import (
        SplineFitOptions,
    )
    from mastapy._private.system_model.part_model.couplings._2659 import (
        SplineLeadRelief,
    )
    from mastapy._private.system_model.part_model.couplings._2660 import (
        SplinePitchErrorInputType,
    )
    from mastapy._private.system_model.part_model.couplings._2661 import (
        SplinePitchErrorOptions,
    )
    from mastapy._private.system_model.part_model.couplings._2662 import SpringDamper
    from mastapy._private.system_model.part_model.couplings._2663 import (
        SpringDamperHalf,
    )
    from mastapy._private.system_model.part_model.couplings._2664 import Synchroniser
    from mastapy._private.system_model.part_model.couplings._2665 import (
        SynchroniserCone,
    )
    from mastapy._private.system_model.part_model.couplings._2666 import (
        SynchroniserHalf,
    )
    from mastapy._private.system_model.part_model.couplings._2667 import (
        SynchroniserPart,
    )
    from mastapy._private.system_model.part_model.couplings._2668 import (
        SynchroniserSleeve,
    )
    from mastapy._private.system_model.part_model.couplings._2669 import TorqueConverter
    from mastapy._private.system_model.part_model.couplings._2670 import (
        TorqueConverterPump,
    )
    from mastapy._private.system_model.part_model.couplings._2671 import (
        TorqueConverterSpeedRatio,
    )
    from mastapy._private.system_model.part_model.couplings._2672 import (
        TorqueConverterTurbine,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.part_model.couplings._2633": ["BeltDrive"],
        "_private.system_model.part_model.couplings._2634": ["BeltDriveType"],
        "_private.system_model.part_model.couplings._2635": ["Clutch"],
        "_private.system_model.part_model.couplings._2636": ["ClutchHalf"],
        "_private.system_model.part_model.couplings._2637": ["ClutchType"],
        "_private.system_model.part_model.couplings._2638": ["ConceptCoupling"],
        "_private.system_model.part_model.couplings._2639": ["ConceptCouplingHalf"],
        "_private.system_model.part_model.couplings._2640": [
            "ConceptCouplingHalfPositioning"
        ],
        "_private.system_model.part_model.couplings._2641": ["Coupling"],
        "_private.system_model.part_model.couplings._2642": ["CouplingHalf"],
        "_private.system_model.part_model.couplings._2643": ["CrowningSpecification"],
        "_private.system_model.part_model.couplings._2644": ["CVT"],
        "_private.system_model.part_model.couplings._2645": ["CVTPulley"],
        "_private.system_model.part_model.couplings._2646": ["PartToPartShearCoupling"],
        "_private.system_model.part_model.couplings._2647": [
            "PartToPartShearCouplingHalf"
        ],
        "_private.system_model.part_model.couplings._2648": ["PitchErrorFlankOptions"],
        "_private.system_model.part_model.couplings._2649": ["Pulley"],
        "_private.system_model.part_model.couplings._2650": [
            "RigidConnectorStiffnessType"
        ],
        "_private.system_model.part_model.couplings._2651": [
            "RigidConnectorTiltStiffnessTypes"
        ],
        "_private.system_model.part_model.couplings._2652": [
            "RigidConnectorToothLocation"
        ],
        "_private.system_model.part_model.couplings._2653": [
            "RigidConnectorToothSpacingType"
        ],
        "_private.system_model.part_model.couplings._2654": ["RigidConnectorTypes"],
        "_private.system_model.part_model.couplings._2655": ["RollingRing"],
        "_private.system_model.part_model.couplings._2656": ["RollingRingAssembly"],
        "_private.system_model.part_model.couplings._2657": ["ShaftHubConnection"],
        "_private.system_model.part_model.couplings._2658": ["SplineFitOptions"],
        "_private.system_model.part_model.couplings._2659": ["SplineLeadRelief"],
        "_private.system_model.part_model.couplings._2660": [
            "SplinePitchErrorInputType"
        ],
        "_private.system_model.part_model.couplings._2661": ["SplinePitchErrorOptions"],
        "_private.system_model.part_model.couplings._2662": ["SpringDamper"],
        "_private.system_model.part_model.couplings._2663": ["SpringDamperHalf"],
        "_private.system_model.part_model.couplings._2664": ["Synchroniser"],
        "_private.system_model.part_model.couplings._2665": ["SynchroniserCone"],
        "_private.system_model.part_model.couplings._2666": ["SynchroniserHalf"],
        "_private.system_model.part_model.couplings._2667": ["SynchroniserPart"],
        "_private.system_model.part_model.couplings._2668": ["SynchroniserSleeve"],
        "_private.system_model.part_model.couplings._2669": ["TorqueConverter"],
        "_private.system_model.part_model.couplings._2670": ["TorqueConverterPump"],
        "_private.system_model.part_model.couplings._2671": [
            "TorqueConverterSpeedRatio"
        ],
        "_private.system_model.part_model.couplings._2672": ["TorqueConverterTurbine"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BeltDrive",
    "BeltDriveType",
    "Clutch",
    "ClutchHalf",
    "ClutchType",
    "ConceptCoupling",
    "ConceptCouplingHalf",
    "ConceptCouplingHalfPositioning",
    "Coupling",
    "CouplingHalf",
    "CrowningSpecification",
    "CVT",
    "CVTPulley",
    "PartToPartShearCoupling",
    "PartToPartShearCouplingHalf",
    "PitchErrorFlankOptions",
    "Pulley",
    "RigidConnectorStiffnessType",
    "RigidConnectorTiltStiffnessTypes",
    "RigidConnectorToothLocation",
    "RigidConnectorToothSpacingType",
    "RigidConnectorTypes",
    "RollingRing",
    "RollingRingAssembly",
    "ShaftHubConnection",
    "SplineFitOptions",
    "SplineLeadRelief",
    "SplinePitchErrorInputType",
    "SplinePitchErrorOptions",
    "SpringDamper",
    "SpringDamperHalf",
    "Synchroniser",
    "SynchroniserCone",
    "SynchroniserHalf",
    "SynchroniserPart",
    "SynchroniserSleeve",
    "TorqueConverter",
    "TorqueConverterPump",
    "TorqueConverterSpeedRatio",
    "TorqueConverterTurbine",
)



"""StraightBevelGearSetCompoundParametricStudyTool"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
    _4570,
)
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_STRAIGHT_BEVEL_GEAR_SET_COMPOUND_PARAMETRIC_STUDY_TOOL = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools.Compound",
    "StraightBevelGearSetCompoundParametricStudyTool",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.part_model.gears import _2604
    from mastapy._private.system_model.analyses_and_results.static_loads import _7113
    from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
        _4533,
    )
    from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
        _4662,
        _4663,
        _4558,
        _4586,
        _4612,
        _4652,
        _4552,
        _4633,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7711,
        _7708,
    )
    from mastapy._private.system_model.analyses_and_results import _2734

    Self = TypeVar("Self", bound="StraightBevelGearSetCompoundParametricStudyTool")
    CastSelf = TypeVar(
        "CastSelf",
        bound="StraightBevelGearSetCompoundParametricStudyTool._Cast_StraightBevelGearSetCompoundParametricStudyTool",
    )


__docformat__ = "restructuredtext en"
__all__ = ("StraightBevelGearSetCompoundParametricStudyTool",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_StraightBevelGearSetCompoundParametricStudyTool:
    """Special nested class for casting StraightBevelGearSetCompoundParametricStudyTool to subclasses."""

    __parent__: "StraightBevelGearSetCompoundParametricStudyTool"

    @property
    def bevel_gear_set_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4570.BevelGearSetCompoundParametricStudyTool":
        return self.__parent__._cast(_4570.BevelGearSetCompoundParametricStudyTool)

    @property
    def agma_gleason_conical_gear_set_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4558.AGMAGleasonConicalGearSetCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4558,
        )

        return self.__parent__._cast(
            _4558.AGMAGleasonConicalGearSetCompoundParametricStudyTool
        )

    @property
    def conical_gear_set_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4586.ConicalGearSetCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4586,
        )

        return self.__parent__._cast(_4586.ConicalGearSetCompoundParametricStudyTool)

    @property
    def gear_set_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4612.GearSetCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4612,
        )

        return self.__parent__._cast(_4612.GearSetCompoundParametricStudyTool)

    @property
    def specialised_assembly_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4652.SpecialisedAssemblyCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4652,
        )

        return self.__parent__._cast(
            _4652.SpecialisedAssemblyCompoundParametricStudyTool
        )

    @property
    def abstract_assembly_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4552.AbstractAssemblyCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4552,
        )

        return self.__parent__._cast(_4552.AbstractAssemblyCompoundParametricStudyTool)

    @property
    def part_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4633.PartCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4633,
        )

        return self.__parent__._cast(_4633.PartCompoundParametricStudyTool)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7711.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7711,
        )

        return self.__parent__._cast(_7711.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7708.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7708,
        )

        return self.__parent__._cast(_7708.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def straight_bevel_gear_set_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "StraightBevelGearSetCompoundParametricStudyTool":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class StraightBevelGearSetCompoundParametricStudyTool(
    _4570.BevelGearSetCompoundParametricStudyTool
):
    """StraightBevelGearSetCompoundParametricStudyTool

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _STRAIGHT_BEVEL_GEAR_SET_COMPOUND_PARAMETRIC_STUDY_TOOL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def component_design(self: "Self") -> "_2604.StraightBevelGearSet":
        """mastapy._private.system_model.part_model.gears.StraightBevelGearSet

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def assembly_design(self: "Self") -> "_2604.StraightBevelGearSet":
        """mastapy._private.system_model.part_model.gears.StraightBevelGearSet

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def properties_changing_all_load_cases(
        self: "Self",
    ) -> "_7113.StraightBevelGearSetLoadCase":
        """mastapy._private.system_model.analyses_and_results.static_loads.StraightBevelGearSetLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PropertiesChangingAllLoadCases

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def assembly_analysis_cases_ready(
        self: "Self",
    ) -> "List[_4533.StraightBevelGearSetParametricStudyTool]":
        """List[mastapy._private.system_model.analyses_and_results.parametric_study_tools.StraightBevelGearSetParametricStudyTool]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def straight_bevel_gears_compound_parametric_study_tool(
        self: "Self",
    ) -> "List[_4662.StraightBevelGearCompoundParametricStudyTool]":
        """List[mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound.StraightBevelGearCompoundParametricStudyTool]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StraightBevelGearsCompoundParametricStudyTool

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def straight_bevel_meshes_compound_parametric_study_tool(
        self: "Self",
    ) -> "List[_4663.StraightBevelGearMeshCompoundParametricStudyTool]":
        """List[mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound.StraightBevelGearMeshCompoundParametricStudyTool]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StraightBevelMeshesCompoundParametricStudyTool

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def assembly_analysis_cases(
        self: "Self",
    ) -> "List[_4533.StraightBevelGearSetParametricStudyTool]":
        """List[mastapy._private.system_model.analyses_and_results.parametric_study_tools.StraightBevelGearSetParametricStudyTool]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_StraightBevelGearSetCompoundParametricStudyTool":
        """Cast to another type.

        Returns:
            _Cast_StraightBevelGearSetCompoundParametricStudyTool
        """
        return _Cast_StraightBevelGearSetCompoundParametricStudyTool(self)



"""RingPinManufacturingError"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from PIL.Image import Image

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import overridable
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_RING_PIN_MANUFACTURING_ERROR = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads",
    "RingPinManufacturingError",
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, TypeVar

    from mastapy._private.bearings.tolerances import _1970

    Self = TypeVar("Self", bound="RingPinManufacturingError")
    CastSelf = TypeVar(
        "CastSelf", bound="RingPinManufacturingError._Cast_RingPinManufacturingError"
    )


__docformat__ = "restructuredtext en"
__all__ = ("RingPinManufacturingError",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RingPinManufacturingError:
    """Special nested class for casting RingPinManufacturingError to subclasses."""

    __parent__: "RingPinManufacturingError"

    @property
    def ring_pin_manufacturing_error(self: "CastSelf") -> "RingPinManufacturingError":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class RingPinManufacturingError(_0.APIBase):
    """RingPinManufacturingError

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _RING_PIN_MANUFACTURING_ERROR

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Name

        if temp is None:
            return ""

        return temp

    @property
    def override_all_pins_roundness_specification(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.OverrideAllPinsRoundnessSpecification

        if temp is None:
            return False

        return temp

    @override_all_pins_roundness_specification.setter
    @enforce_parameter_types
    def override_all_pins_roundness_specification(self: "Self", value: "bool") -> None:
        self.wrapped.OverrideAllPinsRoundnessSpecification = (
            bool(value) if value is not None else False
        )

    @property
    def pin_angular_position_error(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.PinAngularPositionError

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @pin_angular_position_error.setter
    @enforce_parameter_types
    def pin_angular_position_error(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.PinAngularPositionError = value

    @property
    def pin_diameter_error(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.PinDiameterError

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @pin_diameter_error.setter
    @enforce_parameter_types
    def pin_diameter_error(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.PinDiameterError = value

    @property
    def pin_radial_position_error(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.PinRadialPositionError

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @pin_radial_position_error.setter
    @enforce_parameter_types
    def pin_radial_position_error(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.PinRadialPositionError = value

    @property
    def pin_roundness_chart(self: "Self") -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PinRoundnessChart

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def show_pin_roundness_chart(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.ShowPinRoundnessChart

        if temp is None:
            return False

        return temp

    @show_pin_roundness_chart.setter
    @enforce_parameter_types
    def show_pin_roundness_chart(self: "Self", value: "bool") -> None:
        self.wrapped.ShowPinRoundnessChart = bool(value) if value is not None else False

    @property
    def roundness_specification(self: "Self") -> "_1970.RoundnessSpecification":
        """mastapy._private.bearings.tolerances.RoundnessSpecification

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RoundnessSpecification

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_RingPinManufacturingError":
        """Cast to another type.

        Returns:
            _Cast_RingPinManufacturingError
        """
        return _Cast_RingPinManufacturingError(self)
